/// <reference path="../typings/main.d.ts" />
"use strict";
var main_1 = require('./main');
exports.MainHtmlCompiler = main_1.MainHtmlCompiler;
var template_1 = require('./template');
exports.TemplateHtmlCompiler = template_1.TemplateHtmlCompiler;
var $ = require('cheerio');
var StaticHtmlCompiler = (function () {
    function StaticHtmlCompiler(mainHtmlCompiler, templateHtmlCompiler) {
        this.mainHtmlCompiler = mainHtmlCompiler || new main_1.MainHtmlCompiler;
        this.templateHtmlCompiler = templateHtmlCompiler || new template_1.TemplateHtmlCompiler;
    }
    StaticHtmlCompiler.prototype.processFilesForTarget = function (files) {
        var mainFiles = [];
        var templateFiles = [];
        files.forEach(function (file) {
            // skips files from node_modules
            if (!!file.getPathInPackage().startsWith('node_modules')) {
                return;
            }
            var $contents = $(file.getContentsAsString());
            var isMain = $contents.closest('head,body').length;
            var isTemplate = $contents.closest(':not(head,body)').length;
            if (isMain && isTemplate) {
                var fileName = file.getBasename();
                var errorMsg = fileName + " has wrong layout";
                throw Error(errorMsg);
            }
            if (isMain > 0) {
                mainFiles.push(file);
            }
            else {
                templateFiles.push(file);
            }
        });
        // Use each compiler with it's files and compile them
        this.mainHtmlCompiler.processFilesForTarget(mainFiles);
        this.templateHtmlCompiler.processFilesForTarget(templateFiles);
    };
    return StaticHtmlCompiler;
}());
exports.StaticHtmlCompiler = StaticHtmlCompiler;
//# sourceMappingURL=index.js.map